var __defProp = Object.defineProperty;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};

// src/index.ts
import { h } from "hastscript";
import { FontStyle } from "shiki";
var renderToHast = (lines, options = {}) => {
  var _a, _b, _c, _d;
  const bg = (_a = options.bg) != null ? _a : "#fff";
  const optionsByLineNumber = groupBy((_b = options.lineOptions) != null ? _b : [], (option) => option.line);
  const root = h("pre", { class: "shiki", style: { "background-color": bg } });
  if (options.langId) {
    root.children.push(h("div", { class: "language-id" }, options.langId));
  }
  const codeElement = h("code");
  root.children.push(codeElement);
  for (const [lineIndex, line] of lines.entries()) {
    const lineNumber = lineIndex + 1;
    const lineOptions = (_c = optionsByLineNumber.get(lineNumber)) != null ? _c : [];
    const lineClasses = getLineClasses(lineOptions);
    const lineSpan = h("span", { className: lineClasses });
    codeElement.children.push(lineSpan);
    for (const token of line) {
      const cssDeclarations = {};
      const color = (_d = token.color) != null ? _d : options.fg;
      if (color)
        cssDeclarations.color = color;
      if (token.fontStyle) {
        if (FontStyle.Italic) {
          cssDeclarations["font-style"] = "italic";
        } else if (FontStyle.Bold) {
          cssDeclarations["font-weight"] = "bold";
        } else if (FontStyle.Underline) {
          cssDeclarations["text-decoration"] = "underline";
        }
      }
      const properties = {};
      if (Object.keys(cssDeclarations).length > 0) {
        properties.style = cssDeclarations;
      }
      lineSpan.children.push(h("span", properties, token.content));
    }
    codeElement.children.push({ type: "text", value: "\n" });
  }
  codeElement.children.pop();
  return root;
};
var codeToHast = (highlighter, code, lang = "text", theme, options) => {
  const tokens = highlighter.codeToThemedTokens(code, lang, theme, {
    includeExplanation: false
  });
  const loadedTheme = highlighter.getTheme(theme);
  return renderToHast(tokens, __spreadValues({
    fg: loadedTheme.fg,
    bg: loadedTheme.bg
  }, options));
};
function groupBy(elements, keyGetter) {
  const map = /* @__PURE__ */ new Map();
  for (const element of elements) {
    const key = keyGetter(element);
    if (map.has(key)) {
      const group = map.get(key);
      group.push(element);
    } else {
      map.set(key, [element]);
    }
  }
  return map;
}
function getLineClasses(lineOptions) {
  var _a;
  const lineClasses = /* @__PURE__ */ new Set(["line"]);
  for (const lineOption of lineOptions) {
    for (const lineClass of (_a = lineOption.classes) != null ? _a : []) {
      lineClasses.add(lineClass);
    }
  }
  return Array.from(lineClasses);
}
export {
  codeToHast,
  renderToHast
};
